<?php

namespace Civi\Api4;

/**
 * Email entity.
 *
 * This entity allows user to add, update, retrieve or delete emails address(es) of a contact.
 *
 * Creating a new email address requires at minimum a contact's ID and email
 *
 * @package Civi\Api4
 */
class Email extends Generic\DAOEntity {

}
